@@ -24,7 +24,7 @@ from adapt.tools.text.trie import Trie
 __author__ = 'seanfitz'
 
 
-class IntentDeterminationEngine(pyee.BaseEventEmitter):
+class IntentDeterminationEngine(pyee.EventEmitter):
     """
     IntentDeterminationEngine
 
@@ -45,7 +45,7 @@ class IntentDeterminationEngine(pyee.BaseEventEmitter):
                 example EnglishTokenizer()
             trie(Trie): tree of matches to Entites
         """
-        pyee.BaseEventEmitter.__init__(self)
+        pyee.EventEmitter.__init__(self)
         self.tokenizer = tokenizer or EnglishTokenizer()
         self.trie = trie or Trie()
         self.regular_expressions_entities = []
@@ -108,7 +108,7 @@ class IntentDeterminationEngine(pyee.BaseEventEmitter):
 
         Args:
             utterance(str): an ascii or unicode string representing natural language speech
-            include_tags(list): includes the parsed tags (including position and confidence)
+            include_tags(bool): includes the parsed tags (including position and confidence)
                 as part of result
             context_manager(list): a context manager to provide context to the utterance
             num_results(int): a maximum number of results to be returned.
